local Completing = LibStub("AceGUI-3.0-Search-EditBox")
local Predictor = {}

local ElioteUtils = LibStub("LibElioteUtils-1.0")
local startsWith = ElioteUtils.startsWith

local events -- just to keep the huge list at the end of the file

function Predictor:GetValues(text, values, max)
	local count = 0

	for _, event in ipairs(events) do
		if (startsWith(event, text:upper())) then
			values[event] = event
			count = count + 1
			if (count >= max) then break end
		end
	end
end

Completing:Register("Event_BrokerAnything", Predictor)

events = {
	-- C_AchievementInfo
	"ACHIEVEMENT_EARNED",
	"ACHIEVEMENT_PLAYER_NAME",
	"ACHIEVEMENT_SEARCH_UPDATED",
	"CRITERIA_COMPLETE",
	"CRITERIA_EARNED",
	"CRITERIA_UPDATE",
	"INSPECT_ACHIEVEMENT_READY",
	"RECEIVED_ACHIEVEMENT_LIST",
	"RECEIVED_ACHIEVEMENT_MEMBER_LIST",
	"TRACKED_ACHIEVEMENT_LIST_CHANGED",
	"TRACKED_ACHIEVEMENT_UPDATE",
	
	-- C_ActionBar
	"ACTIONBAR_HIDEGRID",
	"ACTIONBAR_PAGE_CHANGED",
	"ACTIONBAR_SHOW_BOTTOMLEFT",
	"ACTIONBAR_SHOWGRID",
	"ACTIONBAR_SLOT_CHANGED",
	"ACTIONBAR_UPDATE_COOLDOWN",
	"ACTIONBAR_UPDATE_STATE",
	"ACTIONBAR_UPDATE_USABLE",
	"PET_BAR_UPDATE",
	"UPDATE_BONUS_ACTIONBAR",
	"UPDATE_EXTRA_ACTIONBAR",
	"UPDATE_MULTI_CAST_ACTIONBAR",
	"UPDATE_OVERRIDE_ACTIONBAR",
	
	-- C_AddOns
	"ADDON_LOADED",
	"ADDONS_UNLOADING",
	"SAVED_VARIABLES_TOO_LARGE",
	
	-- C_AdventureJournal
	"AJ_DUNGEON_ACTION",
	"AJ_OPEN",
	"AJ_PVE_LFG_ACTION",
	"AJ_PVP_ACTION",
	"AJ_PVP_LFG_ACTION",
	"AJ_PVP_RBG_ACTION",
	"AJ_PVP_SKIRMISH_ACTION",
	"AJ_QUEST_LOG_OPEN",
	"AJ_RAID_ACTION",
	"AJ_REFRESH_DISPLAY",
	"AJ_REWARD_DATA_RECEIVED",

	-- C_AdventureMap
	"ADVENTURE_MAP_CLOSE",
	"ADVENTURE_MAP_OPEN",
	"ADVENTURE_MAP_QUEST_UPDATE",
	"ADVENTURE_MAP_UPDATE_INSETS",
	"ADVENTURE_MAP_UPDATE_POIS",
	
	-- C_AlliedRaces
	"ALLIED_RACE_CLOSE",
	"ALLIED_RACE_OPEN",
	
	-- C_AreaPoiInfo
	"AREA_POIS_UPDATED",
	
	-- C_ArtifactUI
	"ARTIFACT_CLOSE",
	"ARTIFACT_ENDGAME_REFUND",
	"ARTIFACT_RELIC_FORGE_CLOSE",
	"ARTIFACT_RELIC_FORGE_PREVIEW_RELIC_CHANGED",
	"ARTIFACT_RELIC_FORGE_UPDATE",
	"ARTIFACT_RELIC_INFO_RECEIVED",
	"ARTIFACT_RESPEC_PROMPT",
	"ARTIFACT_TIER_CHANGED",
	"ARTIFACT_UPDATE",
	"ARTIFACT_XP_UPDATE",
	
	-- C_AuctionHouse
	"AUCTION_BIDDER_LIST_UPDATE",
	"AUCTION_HOUSE_CLOSED",
	"AUCTION_HOUSE_DISABLED",
	"AUCTION_HOUSE_SCRIPT_DEPRECATED",
	"AUCTION_HOUSE_SHOW",
	"AUCTION_ITEM_LIST_UPDATE",
	"AUCTION_MULTISELL_FAILURE",
	"AUCTION_MULTISELL_START",
	"AUCTION_MULTISELL_UPDATE",
	"AUCTION_OWNED_LIST_UPDATE",
	"NEW_AUCTION_UPDATE",
	
	-- C_AzeriteEmpoweredItem
	"AZERITE_EMPOWERED_ITEM_EQUIPPED_STATUS_CHANGED",
	"AZERITE_EMPOWERED_ITEM_SELECTION_UPDATED",
	"RESPEC_AZERITE_EMPOWERED_ITEM_CLOSED",
	"RESPEC_AZERITE_EMPOWERED_ITEM_OPENED",
	
	-- C_AzeriteEssence
	"AZERITE_ESSENCE_ACTIVATED",
	"AZERITE_ESSENCE_ACTIVATION_FAILED",
	"AZERITE_ESSENCE_CHANGED",
	"AZERITE_ESSENCE_FORGE_CLOSE",
	"AZERITE_ESSENCE_FORGE_OPEN",
	"AZERITE_ESSENCE_MILESTONE_UNLOCKED",
	"AZERITE_ESSENCE_UPDATE",
	"PENDING_AZERITE_ESSENCE_CHANGED",
	
	-- C_AzeriteItem
	"AZERITE_ITEM_EXPERIENCE_CHANGED",
	"AZERITE_ITEM_POWER_LEVEL_CHANGED",
	
	-- C_Bank
	"BANK_BAG_SLOT_FLAGS_UPDATED",
	"BANKFRAME_CLOSED",
	"BANKFRAME_OPENED",
	"PLAYERBANKBAGSLOTS_CHANGED",
	"PLAYERBANKSLOTS_CHANGED",
	"PLAYERREAGENTBANKSLOTS_CHANGED",
	"REAGENTBANK_PURCHASED",
	"REAGENTBANK_UPDATE",
	
	-- C_BarberShop
	"BARBER_SHOP_APPEARANCE_APPLIED",
	"BARBER_SHOP_CLOSE",
	"BARBER_SHOP_COST_UPDATE",
	"BARBER_SHOP_OPEN",
	"BARBER_SHOP_SUCCESS",
	
	-- C_BattlePet
	"PET_BATTLE_ABILITY_CHANGED",
	"PET_BATTLE_ACTION_SELECTED",
	"PET_BATTLE_AURA_APPLIED",
	"PET_BATTLE_AURA_CANCELED",
	"PET_BATTLE_AURA_CHANGED",
	"PET_BATTLE_CAPTURED",
	"PET_BATTLE_CLOSE",
	"PET_BATTLE_FINAL_ROUND",
	"PET_BATTLE_HEALTH_CHANGED",
	"PET_BATTLE_LEVEL_CHANGED",
	"PET_BATTLE_MAX_HEALTH_CHANGED",
	"PET_BATTLE_OPENING_DONE",
	"PET_BATTLE_OPENING_START",
	"PET_BATTLE_OVER",
	"PET_BATTLE_OVERRIDE_ABILITY",
	"PET_BATTLE_PET_CHANGED",
	"PET_BATTLE_PET_ROUND_PLAYBACK_COMPLETE",
	"PET_BATTLE_PET_ROUND_RESULTS",
	"PET_BATTLE_PET_TYPE_CHANGED",
	"PET_BATTLE_PVP_DUEL_REQUEST_CANCEL",
	"PET_BATTLE_PVP_DUEL_REQUESTED",
	"PET_BATTLE_QUEUE_PROPOSAL_ACCEPTED",
	"PET_BATTLE_QUEUE_PROPOSAL_DECLINED",
	"PET_BATTLE_QUEUE_PROPOSE_MATCH",
	"PET_BATTLE_QUEUE_STATUS",
	"PET_BATTLE_XP_CHANGED",
	
	-- C_BlackMarketInfo
	"BLACK_MARKET_BID_RESULT",
	"BLACK_MARKET_CLOSE",
	"BLACK_MARKET_ITEM_UPDATE",
	"BLACK_MARKET_OPEN",
	"BLACK_MARKET_OUTBID",
	"BLACK_MARKET_UNAVAILABLE",
	"BLACK_MARKET_WON",
	
	-- C_Browser
	"SIMPLE_BROWSER_WEB_ERROR",
	"SIMPLE_BROWSER_WEB_PROXY_FAILED",
	"SIMPLE_CHECKOUT_CLOSED",
	
	-- C_Calendar
	"CALENDAR_ACTION_PENDING",
	"CALENDAR_CLOSE_EVENT",
	"CALENDAR_EVENT_ALARM",
	"CALENDAR_NEW_EVENT",
	"CALENDAR_OPEN_EVENT",
	"CALENDAR_UPDATE_ERROR",
	"CALENDAR_UPDATE_ERROR_WITH_COUNT",
	"CALENDAR_UPDATE_ERROR_WITH_PLAYER_NAME",
	"CALENDAR_UPDATE_EVENT",
	"CALENDAR_UPDATE_EVENT_LIST",
	"CALENDAR_UPDATE_GUILD_EVENTS",
	"CALENDAR_UPDATE_INVITE_LIST",
	"CALENDAR_UPDATE_PENDING_INVITES",
	
	-- C_ChallengeMode
	"CHALLENGE_MODE_COMPLETED",
	"CHALLENGE_MODE_DEATH_COUNT_UPDATED",
	"CHALLENGE_MODE_KEYSTONE_RECEPTABLE_OPEN",
	"CHALLENGE_MODE_KEYSTONE_SLOTTED",
	"CHALLENGE_MODE_LEADERS_UPDATE",
	"CHALLENGE_MODE_MAPS_UPDATE",
	"CHALLENGE_MODE_MEMBER_INFO_UPDATED",
	"CHALLENGE_MODE_RESET",
	"CHALLENGE_MODE_START",
	
	-- C_ChatInfo
	"ALTERNATIVE_DEFAULT_LANGUAGE_CHANGED",
	"BN_CHAT_MSG_ADDON",
	"CHANNEL_COUNT_UPDATE",
	"CHANNEL_FLAGS_UPDATED",
	"CHANNEL_INVITE_REQUEST",
	"CHANNEL_LEFT",
	"CHANNEL_PASSWORD_REQUEST",
	"CHANNEL_ROSTER_UPDATE",
	"CHANNEL_UI_UPDATE",
	"CHAT_COMBAT_MSG_ARENA_POINTS_GAIN",
	"CHAT_MSG_ACHIEVEMENT",
	"CHAT_MSG_ADDON",
	"CHAT_MSG_ADDON_LOGGED",
	"CHAT_MSG_AFK",
	"CHAT_MSG_BG_SYSTEM_ALLIANCE",
	"CHAT_MSG_BG_SYSTEM_HORDE",
	"CHAT_MSG_BG_SYSTEM_NEUTRAL",
	"CHAT_MSG_BN",
	"CHAT_MSG_BN_INLINE_TOAST_ALERT",
	"CHAT_MSG_BN_INLINE_TOAST_BROADCAST",
	"CHAT_MSG_BN_INLINE_TOAST_BROADCAST_INFORM",
	"CHAT_MSG_BN_INLINE_TOAST_CONVERSATION",
	"CHAT_MSG_BN_WHISPER",
	"CHAT_MSG_BN_WHISPER_INFORM",
	"CHAT_MSG_BN_WHISPER_PLAYER_OFFLINE",
	"CHAT_MSG_CHANNEL",
	"CHAT_MSG_CHANNEL_JOIN",
	"CHAT_MSG_CHANNEL_LEAVE",
	"CHAT_MSG_CHANNEL_LIST",
	"CHAT_MSG_CHANNEL_NOTICE",
	"CHAT_MSG_CHANNEL_NOTICE_USER",
	"CHAT_MSG_COMBAT_FACTION_CHANGE",
	"CHAT_MSG_COMBAT_HONOR_GAIN",
	"CHAT_MSG_COMBAT_MISC_INFO",
	"CHAT_MSG_COMBAT_XP_GAIN",
	"CHAT_MSG_COMMUNITIES_CHANNEL",
	"CHAT_MSG_CURRENCY",
	"CHAT_MSG_DND",
	"CHAT_MSG_EMOTE",
	"CHAT_MSG_FILTERED",
	"CHAT_MSG_GUILD",
	"CHAT_MSG_GUILD_ACHIEVEMENT",
	"CHAT_MSG_GUILD_ITEM_LOOTED",
	"CHAT_MSG_IGNORED",
	"CHAT_MSG_INSTANCE_CHAT",
	"CHAT_MSG_INSTANCE_CHAT_LEADER",
	"CHAT_MSG_LOOT",
	"CHAT_MSG_MONEY",
	"CHAT_MSG_MONSTER_EMOTE",
	"CHAT_MSG_MONSTER_PARTY",
	"CHAT_MSG_MONSTER_SAY",
	"CHAT_MSG_MONSTER_WHISPER",
	"CHAT_MSG_MONSTER_YELL",
	"CHAT_MSG_OFFICER",
	"CHAT_MSG_OPENING",
	"CHAT_MSG_PARTY",
	"CHAT_MSG_PARTY_LEADER",
	"CHAT_MSG_PET_BATTLE_COMBAT_LOG",
	"CHAT_MSG_PET_BATTLE_INFO",
	"CHAT_MSG_PET_INFO",
	"CHAT_MSG_RAID",
	"CHAT_MSG_RAID_BOSS_EMOTE",
	"CHAT_MSG_RAID_BOSS_WHISPER",
	"CHAT_MSG_RAID_LEADER",
	"CHAT_MSG_RAID_WARNING",
	"CHAT_MSG_RESTRICTED",
	"CHAT_MSG_SAY",
	"CHAT_MSG_SKILL",
	"CHAT_MSG_SYSTEM",
	"CHAT_MSG_TARGETICONS",
	"CHAT_MSG_TEXT_EMOTE",
	"CHAT_MSG_TRADESKILLS",
	"CHAT_MSG_WHISPER",
	"CHAT_MSG_WHISPER_INFORM",
	"CHAT_MSG_YELL",
	"CHAT_SERVER_DISCONNECTED",
	"CHAT_SERVER_RECONNECTED",
	"CLEAR_BOSS_EMOTES",
	"LANGUAGE_LIST_CHANGED",
	"QUEST_BOSS_EMOTE",
	"RAID_BOSS_EMOTE",
	"RAID_BOSS_WHISPER",
	"RAID_INSTANCE_WELCOME",
	"UPDATE_CHAT_COLOR",
	"UPDATE_CHAT_COLOR_NAME_BY_CLASS",
	"UPDATE_CHAT_WINDOWS",
	"UPDATE_FLOATING_CHAT_WINDOWS",
	
	-- C_Cinematic
	"CINEMATIC_START",
	"CINEMATIC_STOP",
	"HIDE_SUBTITLE",
	"PLAY_MOVIE",
	
	-- C_ClassTrial
	"CLASS_TRIAL_TIMER_START",
	"CLASS_TRIAL_UPGRADE_COMPLETE",
	
	-- C_Club
	"AVATAR_LIST_UPDATED",
	"CLUB_ADDED",
	"CLUB_ERROR",
	"CLUB_INVITATION_ADDED_FOR_SELF",
	"CLUB_INVITATION_REMOVED_FOR_SELF",
	"CLUB_INVITATIONS_RECEIVED_FOR_CLUB",
	"CLUB_MEMBER_ADDED",
	"CLUB_MEMBER_PRESENCE_UPDATED",
	"CLUB_MEMBER_REMOVED",
	"CLUB_MEMBER_ROLE_UPDATED",
	"CLUB_MEMBER_UPDATED",
	"CLUB_MESSAGE_ADDED",
	"CLUB_MESSAGE_HISTORY_RECEIVED",
	"CLUB_MESSAGE_UPDATED",
	"CLUB_REMOVED",
	"CLUB_REMOVED_MESSAGE",
	"CLUB_SELF_MEMBER_ROLE_UPDATED",
	"CLUB_STREAM_ADDED",
	"CLUB_STREAM_REMOVED",
	"CLUB_STREAM_SUBSCRIBED",
	"CLUB_STREAM_UNSUBSCRIBED",
	"CLUB_STREAM_UPDATED",
	"CLUB_STREAMS_LOADED",
	"CLUB_TICKET_CREATED",
	"CLUB_TICKET_RECEIVED",
	"CLUB_TICKETS_RECEIVED",
	"CLUB_UPDATED",
	"INITIAL_CLUBS_LOADED",
	"STREAM_VIEW_MARKER_UPDATED",
	
	-- C_ClubFinder
	"CLUB_FINDER_CLUB_LIST_RETURNED",
	"CLUB_FINDER_MEMBERSHIP_LIST_CHANGED",
	"CLUB_FINDER_PLAYER_PENDING_LIST_RECIEVED",
	"CLUB_FINDER_POST_UPDATED",
	"CLUB_FINDER_RECRUIT_LIST_CHANGED",
	"CLUB_FINDER_RECRUITS_UPDATED",
	
	-- C_CombatLog
	"COMBAT_LOG_EVENT",
	"COMBAT_LOG_EVENT_UNFILTERED",
	"COMBAT_TEXT_UPDATE",
	
	-- C_Commentator
	"COMMENTATOR_ENTER_WORLD",
	"COMMENTATOR_MAP_UPDATE",
	"COMMENTATOR_PLAYER_NAME_OVERRIDE_UPDATE",
	"COMMENTATOR_PLAYER_UPDATE",
	
	-- C_CompactUnitFrames
	"COMPACT_UNIT_FRAME_PROFILES_LOADED",
	
	-- C_Console
	"CONSOLE_CLEAR",
	"CONSOLE_COLORS_CHANGED",
	"CONSOLE_FONT_SIZE_CHANGED",
	"CONSOLE_LOG",
	"CONSOLE_MESSAGE",
	"CVAR_UPDATE",
	"GLUE_CONSOLE_LOG",
	"TOGGLE_CONSOLE",
	
	-- C_Container
	"BAG_CLOSED",
	"BAG_NEW_ITEMS_UPDATED",
	"BAG_OPEN",
	"BAG_OVERFLOW_WITH_FULL_INVENTORY",
	"BAG_SLOT_FLAGS_UPDATED",
	"BAG_UPDATE",
	"BAG_UPDATE_COOLDOWN",
	"BAG_UPDATE_DELAYED",
	"EQUIP_BIND_TRADEABLE_CONFIRM",
	"INVENTORY_SEARCH_UPDATE",
	"ITEM_LOCK_CHANGED",
	"ITEM_LOCKED",
	"ITEM_UNLOCKED",
	
	-- C_ContributionCollector
	"CONTRIBUTION_CHANGED",
	"CONTRIBUTION_COLLECTOR_CLOSE",
	"CONTRIBUTION_COLLECTOR_OPEN",
	"CONTRIBUTION_COLLECTOR_PENDING",
	"CONTRIBUTION_COLLECTOR_UPDATE",
	"CONTRIBUTION_COLLECTOR_UPDATE_SINGLE",
	
	-- C_CurrencyInfo
	"CURRENCY_DISPLAY_UPDATE",
	"PLAYER_MONEY",
	
	-- C_Cursor
	"BATTLE_PET_CURSOR_CLEAR",
	"COMMUNITIES_STREAM_CURSOR_CLEAR",
	"CURSOR_UPDATE",
	"MOUNT_CURSOR_CLEAR",
	
	-- C_DeathInfo
	"AREA_SPIRIT_HEALER_IN_RANGE",
	"AREA_SPIRIT_HEALER_OUT_OF_RANGE",
	"CEMETERY_PREFERENCE_UPDATED",
	"CONFIRM_XP_LOSS",
	"CORPSE_IN_INSTANCE",
	"CORPSE_IN_RANGE",
	"CORPSE_OUT_OF_RANGE",
	"PLAYER_ALIVE",
	"PLAYER_DEAD",
	"PLAYER_SKINNED",
	"PLAYER_UNGHOST",
	"REQUEST_CEMETERY_LIST_RESPONSE",
	"RESURRECT_REQUEST",
	"SELF_RES_SPELL_CHANGED",
	
	-- C_DuelInfo
	"DUEL_FINISHED",
	"DUEL_INBOUNDS",
	"DUEL_OUTOFBOUNDS",
	"DUEL_REQUESTED",
	
	-- C_EncounterInfo
	"BOSS_KILL",
	"DISABLE_LOW_LEVEL_RAID",
	"ENABLE_LOW_LEVEL_RAID",
	"ENCOUNTER_END",
	"ENCOUNTER_START",
	"INSTANCE_LOCK_START",
	"INSTANCE_LOCK_STOP",
	"INSTANCE_LOCK_WARNING",
	"RAID_TARGET_UPDATE",
	"UPDATE_INSTANCE_INFO",
	
	-- C_EncounterJournal
	"EJ_DIFFICULTY_UPDATE",
	"EJ_LOOT_DATA_RECIEVED",
	
	-- C_EquipmentSet
	"EQUIPMENT_SETS_CHANGED",
	"EQUIPMENT_SWAP_FINISHED",
	"EQUIPMENT_SWAP_PENDING",
	"TRANSMOG_OUTFITS_CHANGED",
	"WEAR_EQUIPMENT_SET",
	
	-- C_FogOfWar
	"FOG_OF_WAR_UPDATED",
	
	-- C_FriendList
	"BATTLETAG_INVITE_SHOW",
	"BN_BLOCK_FAILED_TOO_MANY",
	"BN_BLOCK_LIST_UPDATED",
	"BN_CHAT_WHISPER_UNDELIVERABLE",
	"BN_CONNECTED",
	"BN_CUSTOM_MESSAGE_CHANGED",
	"BN_CUSTOM_MESSAGE_LOADED",
	"BN_DISCONNECTED",
	"BN_FRIEND_ACCOUNT_OFFLINE",
	"BN_FRIEND_ACCOUNT_ONLINE",
	"BN_FRIEND_INFO_CHANGED",
	"BN_FRIEND_INVITE_ADDED",
	"BN_FRIEND_INVITE_LIST_INITIALIZED",
	"BN_FRIEND_INVITE_REMOVED",
	"BN_FRIEND_LIST_SIZE_CHANGED",
	"BN_INFO_CHANGED",
	"BN_REQUEST_FOF_SUCCEEDED",
	"FRIENDLIST_UPDATE",
	"IGNORELIST_UPDATE",
	"MUTELIST_UPDATE",
	"WHO_LIST_UPDATE",
	
	-- C_GMTicketInfo
	"GM_PLAYER_INFO",
	"ITEM_RESTORATION_BUTTON_STATUS",
	"PETITION_CLOSED",
	"PETITION_SHOW",
	"PLAYER_REPORT_SUBMITTED",
	"QUICK_TICKET_SYSTEM_STATUS",
	"QUICK_TICKET_THROTTLE_CHANGED",
	"UPDATE_WEB_TICKET",
	
	-- C_Garrison
	"GARRISON_ARCHITECT_CLOSED",
	"GARRISON_ARCHITECT_OPENED",
	"GARRISON_BUILDING_ACTIVATABLE",
	"GARRISON_BUILDING_ACTIVATED",
	"GARRISON_BUILDING_ERROR",
	"GARRISON_BUILDING_LIST_UPDATE",
	"GARRISON_BUILDING_PLACED",
	"GARRISON_BUILDING_REMOVED",
	"GARRISON_BUILDING_UPDATE",
	"GARRISON_FOLLOWER_ADDED",
	"GARRISON_FOLLOWER_CATEGORIES_UPDATED",
	"GARRISON_FOLLOWER_DURABILITY_CHANGED",
	"GARRISON_FOLLOWER_LIST_UPDATE",
	"GARRISON_FOLLOWER_REMOVED",
	"GARRISON_FOLLOWER_UPGRADED",
	"GARRISON_FOLLOWER_XP_CHANGED",
	"GARRISON_HIDE_LANDING_PAGE",
	"GARRISON_INVASION_AVAILABLE",
	"GARRISON_INVASION_UNAVAILABLE",
	"GARRISON_LANDINGPAGE_SHIPMENTS",
	"GARRISON_MISSION_AREA_BONUS_ADDED",
	"GARRISON_MISSION_BONUS_ROLL_COMPLETE",
	"GARRISON_MISSION_COMPLETE_RESPONSE",
	"GARRISON_MISSION_FINISHED",
	"GARRISON_MISSION_LIST_UPDATE",
	"GARRISON_MISSION_NPC_CLOSED",
	"GARRISON_MISSION_NPC_OPENED",
	"GARRISON_MISSION_REWARD_INFO",
	"GARRISON_MISSION_STARTED",
	"GARRISON_MONUMENT_CLOSE_UI",
	"GARRISON_MONUMENT_LIST_LOADED",
	"GARRISON_MONUMENT_REPLACED",
	"GARRISON_MONUMENT_SELECTED_TROPHY_ID_LOADED",
	"GARRISON_MONUMENT_SHOW_UI",
	"GARRISON_RANDOM_MISSION_ADDED",
	"GARRISON_RECALL_PORTAL_LAST_USED_TIME",
	"GARRISON_RECALL_PORTAL_USED",
	"GARRISON_RECRUIT_FOLLOWER_RESULT",
	"GARRISON_RECRUITMENT_FOLLOWERS_GENERATED",
	"GARRISON_RECRUITMENT_NPC_CLOSED",
	"GARRISON_RECRUITMENT_NPC_OPENED",
	"GARRISON_RECRUITMENT_READY",
	"GARRISON_SHIPMENT_RECEIVED",
	"GARRISON_SHIPYARD_NPC_CLOSED",
	"GARRISON_SHIPYARD_NPC_OPENED",
	"GARRISON_SHOW_LANDING_PAGE",
	"GARRISON_TALENT_COMPLETE",
	"GARRISON_TALENT_NPC_CLOSED",
	"GARRISON_TALENT_NPC_OPENED",
	"GARRISON_TALENT_UPDATE",
	"GARRISON_TRADESKILL_NPC_CLOSED",
	"GARRISON_UPDATE",
	"GARRISON_UPGRADEABLE_RESULT",
	"GARRISON_USE_PARTY_GARRISON_CHANGED",
	"SHIPMENT_CRAFTER_CLOSED",
	"SHIPMENT_CRAFTER_INFO",
	"SHIPMENT_CRAFTER_OPENED",
	"SHIPMENT_CRAFTER_REAGENT_UPDATE",
	"SHIPMENT_UPDATE",
	
	-- C_GlyphInfo
	"ACTIVATE_GLYPH",
	"CANCEL_GLYPH_CAST",
	"USE_GLYPH",
	
	-- C_GossipInfo
	"DYNAMIC_GOSSIP_POI_UPDATED",
	"GOSSIP_CLOSED",
	"GOSSIP_CONFIRM",
	"GOSSIP_CONFIRM_CANCEL",
	"GOSSIP_ENTER_CODE",
	"GOSSIP_SHOW",
	
	-- C_GuildBank
	"GUILDBANK_ITEM_LOCK_CHANGED",
	"GUILDBANK_TEXT_CHANGED",
	"GUILDBANK_UPDATE_MONEY",
	"GUILDBANK_UPDATE_TABS",
	"GUILDBANK_UPDATE_TEXT",
	"GUILDBANK_UPDATE_WITHDRAWMONEY",
	"GUILDBANKBAGSLOTS_CHANGED",
	"GUILDBANKFRAME_CLOSED",
	"GUILDBANKFRAME_OPENED",
	"GUILDBANKLOG_UPDATE",
	
	-- C_GuildInfo
	"CLOSE_TABARD_FRAME",
	"DISABLE_DECLINE_GUILD_INVITE",
	"ENABLE_DECLINE_GUILD_INVITE",
	"GUILD_CHALLENGE_COMPLETED",
	"GUILD_CHALLENGE_UPDATED",
	"GUILD_EVENT_LOG_UPDATE",
	"GUILD_INVITE_CANCEL",
	"GUILD_INVITE_REQUEST",
	"GUILD_MOTD",
	"GUILD_NEWS_UPDATE",
	"GUILD_PARTY_STATE_UPDATED",
	"GUILD_RANKS_UPDATE",
	"GUILD_RECIPE_KNOWN_BY_MEMBERS",
	"GUILD_REGISTRAR_CLOSED",
	"GUILD_REGISTRAR_SHOW",
	"GUILD_RENAME_REQUIRED",
	"GUILD_REWARDS_LIST",
	"GUILD_ROSTER_UPDATE",
	"GUILD_TRADESKILL_UPDATE",
	"GUILDTABARD_UPDATE",
	"OPEN_TABARD_FRAME",
	"PLAYER_GUILD_UPDATE",
	"REQUIRED_GUILD_RENAME_RESULT",
	"TABARD_CANSAVE_CHANGED",
	"TABARD_SAVE_PENDING",
	
	-- C_HeirloomInfo
	"HEIRLOOM_UPGRADE_TARGETING_CHANGED",
	"HEIRLOOMS_UPDATED",
	
	-- C_InstanceEncounter
	"INSTANCE_ENCOUNTER_ADD_TIMER",
	"INSTANCE_ENCOUNTER_ENGAGE_UNIT",
	"INSTANCE_ENCOUNTER_OBJECTIVE_COMPLETE",
	"INSTANCE_ENCOUNTER_OBJECTIVE_START",
	"INSTANCE_ENCOUNTER_OBJECTIVE_UPDATE",
	
	-- C_IslandsInfo
	"ISLAND_AZERITE_GAIN",
	
	-- C_IslandsQueue
	"ISLANDS_QUEUE_CLOSE",
	"ISLANDS_QUEUE_OPEN",
	
	-- C_Item
	"ACTION_WILL_BIND_ITEM",
	"BIND_ENCHANT",
	"CHARACTER_ITEM_FIXUP_NOTIFICATION",
	"CONFIRM_BEFORE_USE",
	"DELETE_ITEM_CONFIRM",
	"END_BOUND_TRADEABLE",
	"GET_ITEM_INFO_RECEIVED",
	"ITEM_DATA_LOAD_RESULT",
	"MERCHANT_CONFIRM_TRADE_TIMER_REMOVAL",
	"REPLACE_ENCHANT",
	"TRADE_REPLACE_ENCHANT",
	"USE_BIND_CONFIRM",
	"USE_NO_REFUND_CONFIRM",
	
	-- C_ItemSocketInfo
	"SOCKET_INFO_ACCEPT",
	"SOCKET_INFO_BIND_CONFIRM",
	"SOCKET_INFO_CLOSE",
	"SOCKET_INFO_FAILURE",
	"SOCKET_INFO_SUCCESS",
	"SOCKET_INFO_UPDATE",
	
	-- C_ItemText
	"ITEM_TEXT_BEGIN",
	"ITEM_TEXT_CLOSED",
	"ITEM_TEXT_READY",
	"ITEM_TEXT_TRANSLATION",
	
	-- C_ItemUpgrade
	"ITEM_UPGRADE_MASTER_CLOSED",
	"ITEM_UPGRADE_MASTER_OPENED",
	"ITEM_UPGRADE_MASTER_SET_ITEM",
	"ITEM_UPGRADE_MASTER_UPDATE",
	
	-- C_KeyBindings
	"MODIFIER_STATE_CHANGED",
	"UPDATE_BINDINGS",
	
	-- C_KnowledgeBase
	"KNOWLEDGE_BASE_ARTICLE_LOAD_FAILURE",
	"KNOWLEDGE_BASE_ARTICLE_LOAD_SUCCESS",
	"KNOWLEDGE_BASE_QUERY_LOAD_FAILURE",
	"KNOWLEDGE_BASE_QUERY_LOAD_SUCCESS",
	"KNOWLEDGE_BASE_SERVER_MESSAGE",
	"KNOWLEDGE_BASE_SETUP_LOAD_FAILURE",
	"KNOWLEDGE_BASE_SETUP_LOAD_SUCCESS",
	"KNOWLEDGE_BASE_SYSTEM_MOTD_UPDATED",
	
	-- C_LFGInfo
	"ISLAND_COMPLETED",
	"LFG_BONUS_FACTION_ID_UPDATED",
	"LFG_BOOT_PROPOSAL_UPDATE",
	"LFG_COMPLETION_REWARD",
	"LFG_INVALID_ERROR_MESSAGE",
	"LFG_LOCK_INFO_RECEIVED",
	"LFG_OFFER_CONTINUE",
	"LFG_OPEN_FROM_GOSSIP",
	"LFG_PROPOSAL_DONE",
	"LFG_PROPOSAL_FAILED",
	"LFG_PROPOSAL_SHOW",
	"LFG_PROPOSAL_SUCCEEDED",
	"LFG_PROPOSAL_UPDATE",
	"LFG_QUEUE_STATUS_UPDATE",
	"LFG_READY_CHECK_DECLINED",
	"LFG_READY_CHECK_HIDE",
	"LFG_READY_CHECK_PLAYER_IS_READY",
	"LFG_READY_CHECK_SHOW",
	"LFG_READY_CHECK_UPDATE",
	"LFG_ROLE_CHECK_DECLINED",
	"LFG_ROLE_CHECK_HIDE",
	"LFG_ROLE_CHECK_ROLE_CHOSEN",
	"LFG_ROLE_CHECK_SHOW",
	"LFG_ROLE_CHECK_UPDATE",
	"LFG_ROLE_UPDATE",
	"LFG_UPDATE",
	"LFG_UPDATE_RANDOM_INFO",
	"UPDATE_LFG_LIST",
	"WARFRONT_COMPLETED",
	
	-- C_LFGList
	"LFG_LIST_ACTIVE_ENTRY_UPDATE",
	"LFG_LIST_APPLICANT_LIST_UPDATED",
	"LFG_LIST_APPLICANT_UPDATED",
	"LFG_LIST_APPLICATION_STATUS_UPDATED",
	"LFG_LIST_AVAILABILITY_UPDATE",
	"LFG_LIST_ENTRY_CREATION_FAILED",
	"LFG_LIST_ENTRY_EXPIRED_TIMEOUT",
	"LFG_LIST_ENTRY_EXPIRED_TOO_MANY_PLAYERS",
	"LFG_LIST_JOINED_GROUP",
	"LFG_LIST_SEARCH_FAILED",
	"LFG_LIST_SEARCH_RESULT_UPDATED",
	"LFG_LIST_SEARCH_RESULTS_RECEIVED",
	
	-- C_LFGuildInfo
	"LF_GUILD_BROWSE_UPDATED",
	"LF_GUILD_MEMBERSHIP_LIST_CHANGED",
	"LF_GUILD_MEMBERSHIP_LIST_UPDATED",
	"LF_GUILD_POST_UPDATED",
	"LF_GUILD_RECRUIT_LIST_CHANGED",
	"LF_GUILD_RECRUITS_UPDATED",
	
	-- C_LoadingScreen
	"LOADING_SCREEN_DISABLED",
	"LOADING_SCREEN_ENABLED",
	
	-- C_Loot
	"AZERITE_EMPOWERED_ITEM_LOOTED",
	"BONUS_ROLL_ACTIVATE",
	"BONUS_ROLL_DEACTIVATE",
	"BONUS_ROLL_FAILED",
	"BONUS_ROLL_RESULT",
	"BONUS_ROLL_STARTED",
	"CANCEL_LOOT_ROLL",
	"CONFIRM_DISENCHANT_ROLL",
	"CONFIRM_LOOT_ROLL",
	"ENCOUNTER_LOOT_RECEIVED",
	"GARRISON_MISSION_BONUS_ROLL_LOOT",
	"ITEM_PUSH",
	"LOOT_BIND_CONFIRM",
	"LOOT_CLOSED",
	"LOOT_HISTORY_AUTO_SHOW",
	"LOOT_HISTORY_FULL_UPDATE",
	"LOOT_HISTORY_ROLL_CHANGED",
	"LOOT_HISTORY_ROLL_COMPLETE",
	"LOOT_ITEM_AVAILABLE",
	"LOOT_ITEM_ROLL_WON",
	"LOOT_JOURNAL_LIST_UPDATE",
	"LOOT_OPENED",
	"LOOT_READY",
	"LOOT_ROLLS_COMPLETE",
	"LOOT_SLOT_CHANGED",
	"LOOT_SLOT_CLEARED",
	"OPEN_MASTER_LOOT_LIST",
	"PET_BATTLE_LOOT_RECEIVED",
	"PLAYER_LOOT_SPEC_UPDATED",
	"QUEST_CURRENCY_LOOT_RECEIVED",
	"QUEST_LOOT_RECEIVED",
	"SHOW_LOOT_TOAST",
	"SHOW_LOOT_TOAST_LEGENDARY_LOOTED",
	"SHOW_LOOT_TOAST_UPGRADE",
	"SHOW_PVP_FACTION_LOOT_TOAST",
	"SHOW_RATED_PVP_REWARD_TOAST",
	"START_LOOT_ROLL",
	"TRIAL_CAP_REACHED_MONEY",
	"UPDATE_MASTER_LOOT_LIST",
	
	-- C_LossOfControl
	"LOSS_OF_CONTROL_ADDED",
	"LOSS_OF_CONTROL_UPDATE",
	"PLAYER_CONTROL_GAINED",
	"PLAYER_CONTROL_LOST",
	
	-- C_Macro
	"EXECUTE_CHAT_LINE",
	"UPDATE_MACROS",
	
	-- C_Mail
	"CLOSE_INBOX_ITEM",
	"MAIL_CLOSED",
	"MAIL_FAILED",
	"MAIL_INBOX_UPDATE",
	"MAIL_LOCK_SEND_ITEMS",
	"MAIL_SEND_INFO_UPDATE",
	"MAIL_SEND_SUCCESS",
	"MAIL_SHOW",
	"MAIL_SUCCESS",
	"MAIL_UNLOCK_SEND_ITEMS",
	"SEND_MAIL_COD_CHANGED",
	"SEND_MAIL_MONEY_CHANGED",
	"UPDATE_PENDING_MAIL",
	
	-- C_Map
	"NEW_WMO_CHUNK",
	"ZONE_CHANGED",
	"ZONE_CHANGED_INDOORS",
	"ZONE_CHANGED_NEW_AREA",
	
	-- C_MapExplorationInfo
	"MAP_EXPLORATION_UPDATED",
	
	-- C_MerchantFrame
	"MERCHANT_CLOSED",
	"MERCHANT_FILTER_ITEM_UPDATE",
	"MERCHANT_SHOW",
	"MERCHANT_UPDATE",
	
	-- C_Minimap
	"MINIMAP_PING",
	"MINIMAP_UPDATE_TRACKING",
	"MINIMAP_UPDATE_ZOOM",
	
	-- C_ModelInfo
	"UI_MODEL_SCENE_INFO_UPDATED",
	
	-- C_MountJournal
	"MOUNT_EQUIPMENT_APPLY_RESULT",
	"MOUNT_JOURNAL_SEARCH_UPDATED",
	"MOUNT_JOURNAL_USABILITY_CHANGED",
	"NEW_MOUNT_ADDED",
	
	-- C_MythicPlus
	"MYTHIC_PLUS_CURRENT_AFFIX_UPDATE",
	"MYTHIC_PLUS_NEW_SEASON_RECORD",
	"MYTHIC_PLUS_NEW_WEEKLY_RECORD",
	
	-- C_NamePlateManager
	"FORBIDDEN_NAME_PLATE_CREATED",
	"FORBIDDEN_NAME_PLATE_UNIT_ADDED",
	"FORBIDDEN_NAME_PLATE_UNIT_REMOVED",
	"NAME_PLATE_CREATED",
	"NAME_PLATE_UNIT_ADDED",
	"NAME_PLATE_UNIT_REMOVED",
	
	-- C_PaperDollInfo
	"AVOIDANCE_UPDATE",
	"CHARACTER_POINTS_CHANGED",
	"CHARACTER_UPGRADE_SPELL_TIER_SET",
	"COMBAT_RATING_UPDATE",
	"DISABLE_XP_GAIN",
	"ENABLE_XP_GAIN",
	"EQUIP_BIND_CONFIRM",
	"INSPECT_HONOR_UPDATE",
	"INSPECT_READY",
	"LIFESTEAL_UPDATE",
	"MASTERY_UPDATE",
	"PET_SPELL_POWER_UPDATE",
	"PLAYER_AVG_ITEM_LEVEL_UPDATE",
	"PLAYER_EQUIPMENT_CHANGED",
	"PVP_POWER_UPDATE",
	"SPEED_UPDATE",
	"SPELL_POWER_CHANGED",
	"STURDINESS_UPDATE",
	"UPDATE_FACTION",
	"UPDATE_INVENTORY_ALERTS",
	"UPDATE_INVENTORY_DURABILITY",
	
	-- C_PartyInfo
	"ENTERED_DIFFERENT_INSTANCE_FROM_PARTY",
	"GROUP_FORMED",
	"GROUP_INVITE_CONFIRMATION",
	"GROUP_JOINED",
	"GROUP_LEFT",
	"GROUP_ROSTER_UPDATE",
	"INSTANCE_BOOT_START",
	"INSTANCE_BOOT_STOP",
	"INSTANCE_GROUP_SIZE_CHANGED",
	"PARTY_INVITE_CANCEL",
	"PARTY_INVITE_REQUEST",
	"PARTY_LEADER_CHANGED",
	"PARTY_LFG_RESTRICTED",
	"PARTY_LOOT_METHOD_CHANGED",
	"PARTY_MEMBER_DISABLE",
	"PARTY_MEMBER_ENABLE",
	"PLAYER_DIFFICULTY_CHANGED",
	"PLAYER_ROLES_ASSIGNED",
	"RAID_ROSTER_UPDATE",
	"READY_CHECK",
	"READY_CHECK_CONFIRM",
	"READY_CHECK_FINISHED",
	"ROLE_CHANGED_INFORM",
	"ROLE_POLL_BEGIN",
	"VOTE_KICK_REASON_NEEDED",
	
	-- C_PetInfo
	"PET_ATTACK_START",
	"PET_ATTACK_STOP",
	"PET_BAR_HIDEGRID",
	"PET_BAR_SHOWGRID",
	"PET_BAR_UPDATE_COOLDOWN",
	"PET_DISMISS_START",
	"PET_FORCE_NAME_DECLENSION",
	"PET_UI_CLOSE",
	"RAISED_AS_GHOUL",
	"UPDATE_POSSESS_BAR",
	"UPDATE_VEHICLE_ACTIONBAR",
	
	-- C_PetJournal
	"BATTLEPET_FORCE_NAME_DECLENSION",
	"COMPANION_LEARNED",
	"COMPANION_UNLEARNED",
	"COMPANION_UPDATE",
	"NEW_PET_ADDED",
	"PET_JOURNAL_AUTO_SLOTTED_PET",
	"PET_JOURNAL_CAGE_FAILED",
	"PET_JOURNAL_LIST_UPDATE",
	"PET_JOURNAL_NEW_BATTLE_SLOT",
	"PET_JOURNAL_PET_DELETED",
	"PET_JOURNAL_PET_RESTORED",
	"PET_JOURNAL_PET_REVOKED",
	"PET_JOURNAL_PETS_HEALED",
	"PET_JOURNAL_TRAP_LEVEL_SET",
	"UPDATE_SUMMONPETS_ACTION",
	
	-- C_PvP
	"ARENA_OPPONENT_UPDATE",
	"ARENA_PREP_OPPONENT_SPECIALIZATIONS",
	"ARENA_SEASON_WORLD_STATE",
	"BATTLEFIELD_QUEUE_TIMEOUT",
	"BATTLEFIELDS_CLOSED",
	"BATTLEFIELDS_SHOW",
	"BATTLEGROUND_OBJECTIVES_UPDATE",
	"BATTLEGROUND_POINTS_UPDATE",
	"GDF_SIM_COMPLETE",
	"HONOR_LEVEL_UPDATE",
	"NOTIFY_PVP_AFK_RESULT",
	"PLAYER_ENTERING_BATTLEGROUND",
	"POST_MATCH_CURRENCY_REWARD_UPDATE",
	"POST_MATCH_ITEM_REWARD_UPDATE",
	"PVP_BRAWL_INFO_UPDATED",
	"PVP_MATCH_ACTIVE",
	"PVP_MATCH_COMPLETE",
	"PVP_MATCH_INACTIVE",
	"PVP_RATED_STATS_UPDATE",
	"PVP_REWARDS_UPDATE",
	"PVP_ROLE_UPDATE",
	"PVP_TYPES_ENABLED",
	"PVP_VEHICLE_INFO_UPDATED",
	"PVP_WORLDSTATE_UPDATE",
	"PVPQUEUE_ANYWHERE_SHOW",
	"PVPQUEUE_ANYWHERE_UPDATE_AVAILABLE",
	"UPDATE_ACTIVE_BATTLEFIELD",
	"UPDATE_BATTLEFIELD_SCORE",
	"UPDATE_BATTLEFIELD_STATUS",
	"WAR_MODE_STATUS_UPDATE",
	"WARGAME_REQUESTED",
	
	-- C_QuestChoice
	"QUEST_CHOICE_CLOSE",
	"QUEST_CHOICE_UPDATE",
	
	-- C_QuestLog
	"QUEST_ACCEPTED",
	"QUEST_AUTOCOMPLETE",
	"QUEST_COMPLETE",
	"QUEST_DETAIL",
	"QUEST_LOG_CRITERIA_UPDATE",
	"QUEST_LOG_UPDATE",
	"QUEST_POI_UPDATE",
	"QUEST_REMOVED",
	"QUEST_TURNED_IN",
	"QUEST_WATCH_LIST_CHANGED",
	"QUEST_WATCH_UPDATE",
	"QUESTLINE_UPDATE",
	"SUPER_TRACKED_QUEST_CHANGED",
	"TASK_PROGRESS_UPDATE",
	"TREASURE_PICKER_CACHE_FLUSH",
	"WAYPOINT_UPDATE",
	"WORLD_QUEST_COMPLETED_BY_SPELL",
	
	-- C_QuestOffer
	"QUEST_ACCEPT_CONFIRM",
	"QUEST_FINISHED",
	"QUEST_GREETING",
	"QUEST_ITEM_UPDATE",
	"QUEST_PROGRESS",
	
	-- C_RecruitAFriend
	"LEVEL_GRANT_PROPOSED",
	"PARTY_REFER_A_FRIEND_UPDATED",
	"RECRUIT_A_FRIEND_CAN_EMAIL",
	"RECRUIT_A_FRIEND_INVITATION_FAILED",
	"RECRUIT_A_FRIEND_INVITER_FRIEND_ADDED",
	"RECRUIT_A_FRIEND_SYSTEM_STATUS",
	"SOR_BY_TEXT_UPDATED",
	"SOR_COUNTS_UPDATED",
	"SOR_START_EXPERIENCE_INCOMPLETE",
	
	-- C_ReportSystem
	"OPEN_REPORT_PLAYER",
	"REPORT_PLAYER_RESULT",
	
	-- C_ResearchInfo
	"ARCHAEOLOGY_CLOSED",
	"ARCHAEOLOGY_FIND_COMPLETE",
	"ARCHAEOLOGY_SURVEY_CAST",
	"ARCHAEOLOGY_TOGGLE",
	"ARTIFACT_DIGSITE_COMPLETE",
	"RESEARCH_ARTIFACT_COMPLETE",
	"RESEARCH_ARTIFACT_DIG_SITE_UPDATED",
	"RESEARCH_ARTIFACT_HISTORY_READY",
	"RESEARCH_ARTIFACT_UPDATE",
	
	-- C_RestrictedActions
	"ADDON_ACTION_BLOCKED",
	"ADDON_ACTION_FORBIDDEN",
	"MACRO_ACTION_BLOCKED",
	"MACRO_ACTION_FORBIDDEN",
	
	-- C_ScenarioInfo
	"SCENARIO_BONUS_OBJECTIVE_COMPLETE",
	"SCENARIO_BONUS_VISIBILITY_UPDATE",
	"SCENARIO_COMPLETED",
	"SCENARIO_CRITERIA_SHOW_STATE_UPDATE",
	"SCENARIO_CRITERIA_UPDATE",
	"SCENARIO_POI_UPDATE",
	"SCENARIO_SPELL_UPDATE",
	"SCENARIO_UPDATE",
	
	-- C_ScrappingMachineUI
	"SCRAPPING_MACHINE_CLOSE",
	"SCRAPPING_MACHINE_ITEM_REMOVED_OR_CANCELLED",
	"SCRAPPING_MACHINE_PENDING_ITEM_CHANGED",
	"SCRAPPING_MACHINE_SCRAPPING_FINISHED",
	"SCRAPPING_MACHINE_SHOW",
	
	-- C_ScriptWarnings
	"LUA_WARNING",
	
	-- C_SecureTransfer
	"SECURE_TRANSFER_CANCEL",
	"SECURE_TRANSFER_CONFIRM_SEND_MAIL",
	"SECURE_TRANSFER_CONFIRM_TRADE_ACCEPT",
	
	-- C_SkillInfo
	"SKILL_LINES_CHANGED",
	
	-- C_Social
	"SOCIAL_ITEM_RECEIVED",
	"TWITTER_LINK_RESULT",
	"TWITTER_POST_RESULT",
	"TWITTER_STATUS_UPDATE",
	
	-- C_SocialQueue
	"SOCIAL_QUEUE_CONFIG_UPDATED",
	"SOCIAL_QUEUE_UPDATE",
	
	-- C_Sound
	"SOUND_DEVICE_UPDATE",
	"SOUNDKIT_FINISHED",
	
	-- C_SpecializationInfo
	"ACTIVE_TALENT_GROUP_CHANGED",
	"CONFIRM_TALENT_WIPE",
	"PET_SPECIALIZATION_CHANGED",
	"PLAYER_LEARN_PVP_TALENT_FAILED",
	"PLAYER_LEARN_TALENT_FAILED",
	"PLAYER_PVP_TALENT_UPDATE",
	"PLAYER_TALENT_UPDATE",
	"SPEC_INVOLUNTARILY_CHANGED",
	"TALENTS_INVOLUNTARILY_RESET",
	
	-- C_Spell
	"SPELL_DATA_LOAD_RESULT",
	
	-- C_SpellActivationOverlay
	"SPELL_ACTIVATION_OVERLAY_GLOW_HIDE",
	"SPELL_ACTIVATION_OVERLAY_GLOW_SHOW",
	"SPELL_ACTIVATION_OVERLAY_HIDE",
	"SPELL_ACTIVATION_OVERLAY_SHOW",
	
	-- C_SpellBook
	"CURRENT_SPELL_CAST_CHANGED",
	"LEARNED_SPELL_IN_TAB",
	"MAX_SPELL_START_RECOVERY_OFFSET_CHANGED",
	"PLAYER_TOTEM_UPDATE",
	"SPELL_FLYOUT_UPDATE",
	"SPELL_PUSHED_TO_ACTIONBAR",
	"SPELL_TEXT_UPDATE",
	"SPELL_UPDATE_CHARGES",
	"SPELL_UPDATE_COOLDOWN",
	"SPELL_UPDATE_ICON",
	"SPELL_UPDATE_USABLE",
	"SPELLS_CHANGED",
	"START_AUTOREPEAT_SPELL",
	"STOP_AUTOREPEAT_SPELL",
	"UNIT_SPELLCAST_SENT",
	"UPDATE_SHAPESHIFT_COOLDOWN",
	"UPDATE_SHAPESHIFT_FORM",
	"UPDATE_SHAPESHIFT_FORMS",
	"UPDATE_SHAPESHIFT_USABLE",
	
	-- C_StableInfo
	"PET_STABLE_CLOSED",
	"PET_STABLE_SHOW",
	"PET_STABLE_UPDATE",
	"PET_STABLE_UPDATE_PAPERDOLL",
	
	-- C_System
	"CAPTUREFRAMES_FAILED",
	"CAPTUREFRAMES_SUCCEEDED",
	"DISABLE_TAXI_BENCHMARK",
	"ENABLE_TAXI_BENCHMARK",
	"GENERIC_ERROR",
	"INITIAL_HOTFIXES_APPLIED",
	"LOC_RESULT",
	"LOGOUT_CANCEL",
	"PLAYER_CAMPING",
	"PLAYER_ENTERING_WORLD",
	"PLAYER_LEAVING_WORLD",
	"PLAYER_LOGIN",
	"PLAYER_LOGOUT",
	"PLAYER_QUITING",
	"SEARCH_DB_LOADED",
	"STREAMING_ICON",
	"SYSMSG",
	"TIME_PLAYED_MSG",
	"UI_ERROR_MESSAGE",
	"UI_INFO_MESSAGE",
	"VARIABLES_LOADED",
	"WOW_MOUSE_NOT_FOUND",
	
	-- C_TalkingHead
	"TALKINGHEAD_CLOSE",
	"TALKINGHEAD_REQUESTED",
	
	-- C_TaxiMap
	"TAXIMAP_CLOSED",
	"TAXIMAP_OPENED",
	
	-- C_ToyBoxInfo
	"NEW_TOY_ADDED",
	"TOYS_UPDATED",
	
	-- C_TradeInfo
	"PLAYER_TRADE_CURRENCY",
	"PLAYER_TRADE_MONEY",
	"TRADE_ACCEPT_UPDATE",
	"TRADE_CLOSED",
	"TRADE_CURRENCY_CHANGED",
	"TRADE_MONEY_CHANGED",
	"TRADE_PLAYER_ITEM_CHANGED",
	"TRADE_POTENTIAL_BIND_ENCHANT",
	"TRADE_POTENTIAL_REMOVE_TRANSMOG",
	"TRADE_REQUEST",
	"TRADE_REQUEST_CANCEL",
	"TRADE_SHOW",
	"TRADE_TARGET_ITEM_CHANGED",
	"TRADE_UPDATE",
	
	-- C_TradeSkillUI
	"NEW_RECIPE_LEARNED",
	"OBLITERUM_FORGE_CLOSE",
	"OBLITERUM_FORGE_PENDING_ITEM_CHANGED",
	"OBLITERUM_FORGE_SHOW",
	"TRADE_SKILL_CLOSE",
	"TRADE_SKILL_DATA_SOURCE_CHANGED",
	"TRADE_SKILL_DATA_SOURCE_CHANGING",
	"TRADE_SKILL_DETAILS_UPDATE",
	"TRADE_SKILL_LIST_UPDATE",
	"TRADE_SKILL_NAME_UPDATE",
	"TRADE_SKILL_SHOW",
	"UPDATE_TRADESKILL_RECAST",
	
	-- C_Trainer
	"TRAINER_CLOSED",
	"TRAINER_DESCRIPTION_UPDATE",
	"TRAINER_SERVICE_INFO_NAME_UPDATE",
	"TRAINER_SHOW",
	"TRAINER_UPDATE",
	
	-- C_Transmog
	"TRANSMOG_COLLECTION_CAMERA_UPDATE",
	"TRANSMOG_COLLECTION_ITEM_UPDATE",
	"TRANSMOG_COLLECTION_SOURCE_ADDED",
	"TRANSMOG_COLLECTION_SOURCE_REMOVED",
	"TRANSMOG_COLLECTION_UPDATED",
	"TRANSMOG_SEARCH_UPDATED",
	"TRANSMOG_SETS_UPDATE_FAVORITE",
	"TRANSMOG_SOURCE_COLLECTABILITY_UPDATE",
	"TRANSMOGRIFY_CLOSE",
	"TRANSMOGRIFY_ITEM_UPDATE",
	"TRANSMOGRIFY_OPEN",
	"TRANSMOGRIFY_SUCCESS",
	"TRANSMOGRIFY_UPDATE",
	
	-- C_Tutorial
	"NPE_TUTORIAL_UPDATE",
	"TUTORIAL_HIGHLIGHT_SPELL",
	"TUTORIAL_TRIGGER",
	"TUTORIAL_UNHIGHLIGHT_SPELL",
	
	-- C_UI
	"UI_SCALE_CHANGED",
	
	-- C_UIWidgetManager
	"UPDATE_ALL_UI_WIDGETS",
	"UPDATE_UI_WIDGET",
	
	-- C_Vehicle
	"PLAYER_GAINS_VEHICLE_DATA",
	"PLAYER_LOSES_VEHICLE_DATA",
	"UNIT_ENTERED_VEHICLE",
	"UNIT_ENTERING_VEHICLE",
	"UNIT_EXITED_VEHICLE",
	"UNIT_EXITING_VEHICLE",
	"VEHICLE_ANGLE_SHOW",
	"VEHICLE_PASSENGERS_CHANGED",
	"VEHICLE_POWER_SHOW",
	"VEHICLE_UPDATE",
	
	-- C_VideoOptions
	"DISPLAY_SIZE_CHANGED",
	"GLUE_SCREENSHOT_FAILED",
	"SCREENSHOT_FAILED",
	"SCREENSHOT_STARTED",
	"SCREENSHOT_SUCCEEDED",
	
	-- C_VignetteInfo
	"VIGNETTE_MINIMAP_UPDATED",
	"VIGNETTES_UPDATED",
	
	-- C_VoiceChat
	"VOICE_CHAT_ACTIVE_INPUT_DEVICE_UPDATED",
	"VOICE_CHAT_ACTIVE_OUTPUT_DEVICE_UPDATED",
	"VOICE_CHAT_AUDIO_CAPTURE_ENERGY",
	"VOICE_CHAT_AUDIO_CAPTURE_STARTED",
	"VOICE_CHAT_AUDIO_CAPTURE_STOPPED",
	"VOICE_CHAT_CHANNEL_ACTIVATED",
	"VOICE_CHAT_CHANNEL_DEACTIVATED",
	"VOICE_CHAT_CHANNEL_DISPLAY_NAME_CHANGED",
	"VOICE_CHAT_CHANNEL_JOINED",
	"VOICE_CHAT_CHANNEL_MEMBER_ACTIVE_STATE_CHANGED",
	"VOICE_CHAT_CHANNEL_MEMBER_ADDED",
	"VOICE_CHAT_CHANNEL_MEMBER_ENERGY_CHANGED",
	"VOICE_CHAT_CHANNEL_MEMBER_GUID_UPDATED",
	"VOICE_CHAT_CHANNEL_MEMBER_MUTE_FOR_ALL_CHANGED",
	"VOICE_CHAT_CHANNEL_MEMBER_MUTE_FOR_ME_CHANGED",
	"VOICE_CHAT_CHANNEL_MEMBER_REMOVED",
	"VOICE_CHAT_CHANNEL_MEMBER_SILENCED_CHANGED",
	"VOICE_CHAT_CHANNEL_MEMBER_SPEAKING_STATE_CHANGED",
	"VOICE_CHAT_CHANNEL_MEMBER_VOLUME_CHANGED",
	"VOICE_CHAT_CHANNEL_MUTE_STATE_CHANGED",
	"VOICE_CHAT_CHANNEL_PTT_CHANGED",
	"VOICE_CHAT_CHANNEL_REMOVED",
	"VOICE_CHAT_CHANNEL_TRANSMIT_CHANGED",
	"VOICE_CHAT_CHANNEL_VOLUME_CHANGED",
	"VOICE_CHAT_COMMUNICATION_MODE_CHANGED",
	"VOICE_CHAT_CONNECTION_SUCCESS",
	"VOICE_CHAT_DEAFENED_CHANGED",
	"VOICE_CHAT_ERROR",
	"VOICE_CHAT_INPUT_DEVICES_UPDATED",
	"VOICE_CHAT_LOGIN",
	"VOICE_CHAT_LOGOUT",
	"VOICE_CHAT_MUTED_CHANGED",
	"VOICE_CHAT_OUTPUT_DEVICES_UPDATED",
	"VOICE_CHAT_PENDING_CHANNEL_JOIN_STATE",
	"VOICE_CHAT_PTT_BUTTON_PRESSED_STATE_CHANGED",
	"VOICE_CHAT_SILENCED_CHANGED",
	
	-- C_VoidStorageInfo
	"VOID_DEPOSIT_WARNING",
	"VOID_STORAGE_CLOSE",
	"VOID_STORAGE_CONTENTS_UPDATE",
	"VOID_STORAGE_DEPOSIT_UPDATE",
	"VOID_STORAGE_OPEN",
	"VOID_STORAGE_UPDATE",
	"VOID_TRANSFER_DONE",
	"VOID_TRANSFER_SUCCESS",
	
	-- C_WorldStateInfo
	"START_TIMER",
	"WORLD_STATE_TIMER_START",
	"WORLD_STATE_TIMER_STOP",
	
	-- C_WowTokenUI
	"TOKEN_AUCTION_SOLD",
	"TOKEN_BUY_CONFIRM_REQUIRED",
	"TOKEN_BUY_RESULT",
	"TOKEN_CAN_VETERAN_BUY_UPDATE",
	"TOKEN_DISTRIBUTIONS_UPDATED",
	"TOKEN_MARKET_PRICE_UPDATED",
	"TOKEN_REDEEM_BALANCE_UPDATED",
	"TOKEN_REDEEM_CONFIRM_REQUIRED",
	"TOKEN_REDEEM_FRAME_SHOW",
	"TOKEN_REDEEM_GAME_TIME_UPDATED",
	"TOKEN_REDEEM_RESULT",
	"TOKEN_SELL_CONFIRM_REQUIRED",
	"TOKEN_SELL_RESULT",
	"TOKEN_STATUS_CHANGED",

	-- Expansion
	"MAX_EXPANSION_LEVEL_UPDATED",
	"MIN_EXPANSION_LEVEL_UPDATED",

	-- Unit
	"ARENA_COOLDOWNS_UPDATE",
	"ARENA_CROWD_CONTROL_SPELL_UPDATE",
	"AUTOFOLLOW_BEGIN",
	"AUTOFOLLOW_END",
	"CANCEL_SUMMON",
	"CONFIRM_BINDER",
	"CONFIRM_SUMMON",
	"HEARTHSTONE_BOUND",
	"HONOR_XP_UPDATE",
	"INCOMING_RESURRECT_CHANGED",
	"INCOMING_SUMMON_CHANGED",
	"KNOWN_TITLES_UPDATE",
	"LOCALPLAYER_PET_RENAMED",
	"MIRROR_TIMER_PAUSE",
	"MIRROR_TIMER_START",
	"MIRROR_TIMER_STOP",
	"NEUTRAL_FACTION_SELECT_RESULT",
	"OBJECT_ENTERED_AOI",
	"OBJECT_LEFT_AOI",
	"PET_BAR_UPDATE_USABLE",
	"PET_UI_UPDATE",
	"PLAYER_DAMAGE_DONE_MODS",
	"PLAYER_ENTER_COMBAT",
	"PLAYER_FARSIGHT_FOCUS_CHANGED",
	"PLAYER_FLAGS_CHANGED",
	"PLAYER_FOCUS_CHANGED",
	"PLAYER_LEAVE_COMBAT",
	"PLAYER_LEVEL_CHANGED",
	"PLAYER_LEVEL_UP",
	"PLAYER_MOUNT_DISPLAY_CHANGED",
	"PLAYER_PVP_KILLS_CHANGED",
	"PLAYER_PVP_RANK_CHANGED",
	"PLAYER_REGEN_DISABLED",
	"PLAYER_REGEN_ENABLED",
	"PLAYER_SPECIALIZATION_CHANGED",
	"PLAYER_STARTED_LOOKING",
	"PLAYER_STARTED_MOVING",
	"PLAYER_STARTED_TURNING",
	"PLAYER_STOPPED_LOOKING",
	"PLAYER_STOPPED_MOVING",
	"PLAYER_STOPPED_TURNING",
	"PLAYER_TARGET_CHANGED",
	"PLAYER_TRIAL_XP_UPDATE",
	"PLAYER_UPDATE_RESTING",
	"PLAYER_XP_UPDATE",
	"PORTRAITS_UPDATED",
	"PROVING_GROUNDS_SCORE_UPDATE",
	"PVP_TIMER_UPDATE",
	"RUNE_POWER_UPDATE",
	"SHOW_FACTION_SELECT_UI",
	"SPELL_CONFIRMATION_PROMPT",
	"SPELL_CONFIRMATION_TIMEOUT",
	"UNIT_ABSORB_AMOUNT_CHANGED",
	"UNIT_ATTACK",
	"UNIT_ATTACK_POWER",
	"UNIT_ATTACK_SPEED",
	"UNIT_AURA",
	"UNIT_CHEAT_TOGGLE_EVENT",
	"UNIT_CLASSIFICATION_CHANGED",
	"UNIT_COMBAT",
	"UNIT_CONNECTION",
	"UNIT_DAMAGE",
	"UNIT_DEFENSE",
	"UNIT_DISPLAYPOWER",
	"UNIT_FACTION",
	"UNIT_FLAGS",
	"UNIT_HEAL_ABSORB_AMOUNT_CHANGED",
	"UNIT_HEAL_PREDICTION",
	"UNIT_HEALTH",
	"UNIT_HEALTH_FREQUENT",
	"UNIT_INVENTORY_CHANGED",
	"UNIT_LEVEL",
	"UNIT_MANA",
	"UNIT_MAXHEALTH",
	"UNIT_MAXPOWER",
	"UNIT_MODEL_CHANGED",
	"UNIT_NAME_UPDATE",
	"UNIT_OTHER_PARTY_CHANGED",
	"UNIT_PET",
	"UNIT_PET_EXPERIENCE",
	"UNIT_PHASE",
	"UNIT_PORTRAIT_UPDATE",
	"UNIT_POWER_BAR_HIDE",
	"UNIT_POWER_BAR_SHOW",
	"UNIT_POWER_BAR_TIMER_UPDATE",
	"UNIT_POWER_FREQUENT",
	"UNIT_POWER_UPDATE",
	"UNIT_QUEST_LOG_CHANGED",
	"UNIT_RANGED_ATTACK_POWER",
	"UNIT_RANGEDDAMAGE",
	"UNIT_RESISTANCES",
	"UNIT_SPELL_HASTE",
	"UNIT_SPELLCAST_CHANNEL_START",
	"UNIT_SPELLCAST_CHANNEL_STOP",
	"UNIT_SPELLCAST_CHANNEL_UPDATE",
	"UNIT_SPELLCAST_DELAYED",
	"UNIT_SPELLCAST_FAILED",
	"UNIT_SPELLCAST_FAILED_QUIET",
	"UNIT_SPELLCAST_INTERRUPTED",
	"UNIT_SPELLCAST_INTERRUPTIBLE",
	"UNIT_SPELLCAST_NOT_INTERRUPTIBLE",
	"UNIT_SPELLCAST_START",
	"UNIT_SPELLCAST_STOP",
	"UNIT_SPELLCAST_SUCCEEDED",
	"UNIT_STATS",
	"UNIT_TARGET",
	"UNIT_TARGETABLE_CHANGED",
	"UNIT_THREAT_LIST_UPDATE",
	"UNIT_THREAT_SITUATION_UPDATE",
	"UPDATE_EXHAUSTION",
	"UPDATE_MOUSEOVER_UNIT",
	"UPDATE_STEALTH",
	"VEHICLE_ANGLE_UPDATE",

	-- Non-Blizzard documented
	-- Not all events are documented in Blizzard API Documentation
	"AUTH_CHALLENGE_FINISHED",
	"AUTH_CHALLENGE_UI_INVALID",
	"BILLING_NAG_DIALOG",
	"DEBUG_MENU_TOGGLED",
	"EVENT_CLASS_TRIAL_TIMER_START",
	"EXPERIMENTAL_CVAR_CONFIRMATION_NEEDED",
	"IGR_BILLING_NAG_DIALOG",
	"PLAYTIME_CHANGED",
	"PRODUCT_ASSIGN_TO_TARGET_FAILED",
	"PRODUCT_CHOICE_UPDATE",
	"PRODUCT_DISTRIBUTIONS_UPDATED",
	"SESSION_TIME_ALERT",
	"STORE_BOOST_AUTO_CONSUMED",
	"STORE_CHARACTER_LIST_RECEIVED",
	"STORE_CONFIRM_PURCHASE",
	"STORE_OPEN_SIMPLE_CHECKOUT",
	"STORE_ORDER_INITIATION_FAILED",
	"STORE_PRODUCTS_UPDATED",
	"STORE_PRODUCT_DELIVERED",
	"STORE_PURCHASE_ERROR",
	"STORE_PURCHASE_LIST_UPDATED",
	"STORE_REFRESH",
	"STORE_STATUS_CHANGED",
	"STORE_VAS_PURCHASE_COMPLETE",
	"STORE_VAS_PURCHASE_ERROR",
	"SUBSCRIPTION_CHANGED_KICK_IMMINENT",
	"TRIAL_CAP_REACHED_LEVEL",
	"TRIAL_STATUS_UPDATE",
	"UPDATE_EXPANSION_LEVEL",
	"UPDATE_GM_STATUS",
}
